# Reset_feedback

*İpucu: Bu eklenti geribildirim (FEEDBACK) ögesinin 0 milisaniye gösterilmesi ile aynı işlevi gerçekleştirir.*

Eğer geribildirim değişkenlerinizi, görevle alakalı olmayan yanıtların geribildirimi karıştırmasına sebep olabilirsiniz. Örneğin, yönerge okunurken basılan bir tuş deneyin ilk bloğuna etki edebilir. Bu nedenle geribildirim değişkeninizi uygun zamanlarda sıfırlamanız gerekir.

Bu eklenti aşağıdaki değişkenleri sıfırlar:

- `total_response_time`
- `total_response`
- `acc`
- `accuracy`
- `avg_rt`
- `average_response_time`

Daha fazla bilgi için:

- <http://osdoc.cogsci.nl/3.2/manual/stimuli/visual/>
